clear
clear matrix
#delimit;
set more off;
set mem 800m;


  
local path "I:\Data\pairfam\Datado\";  

use "`path'\anchorpartnerlong.dta", clear;
 
*****************************************************************************************************************  
*GENERATE VARIABLES; please not that this file also generates variables that are not included in the analyses
*****************************************************************************************************************  
 
****************************************************************************************** 
*SELECT SAMPLE. heterosexual couples only. id=Anchor ID and pid=Partner ID;
****************************************************************************************** 

sum id pid; 
keep if id~=. & pid~=.;
 
keep if (sex==1 & psex==2) | (sex==2 & psex==1);

sum id pid; 
 
* DO VARIABLES;

*Relationship status [3 categories];
gen rstatus = .;
replace rstatus = 1 if relstat==2;
replace rstatus = 2 if relstat==3;
replace rstatus = 3 if relstat==4;

label var rstatus "Relationship status";
label define rstatuss 1"LAT" 2"COHAB" 3"Married";
label val rstatus rstatuss;
tab rstatus;
sum id pid;  

*Duration of relationship in months [Group Variable];
keep if reldur>=0; /*Continuous variable already in data*/

gen durelg = .;

replace durelg = 1 if reldur>=0 & reldur<12;
replace durelg = 2 if reldur>=12 & reldur<48;
replace durelg = 3 if reldur>=48 & reldur<84;
replace durelg = 4 if reldur>=84 & reldur<168;
replace durelg = 5 if reldur>=168;
tab durelg;

label var durelg "Duration of relationship";
label define durelgx 1"0-11 months" 2"12-47 months" 3"48-83 months" 4"84-167 months" 5"168 months and more";; 
label val durelg durelgx;
tab durelg;
 

* Years of education for female male persons (anchor and partner);
replace yeduc = . if yeduc<0; /*Continuous variable for anchor already in data*/
replace pyeduc = . if pyeduc<0; /*Continuous variable for partner already in data*/

gen yeducf = yeduc if sex==2 ;
replace yeducf = pyeduc if  psex==2;

gen yeducm = yeduc if sex==1 ;
replace yeducm = pyeduc if  psex==1;


* Age squared and age for female and male persons (anchor and partner);
replace age = . if age<0; /*Continuous variable for anchor already in data*/
replace page = . if page<0;  /*Continuous variable for partner already in data*/

gen age2 = age^2;
gen page2 = page^2;

gen agef = age if sex==2 ;
replace agef = page if  psex==2;

gen agem = age if sex==1 ;
replace agem = page if  psex==1;

gen agef2 = agef^2;
gen agem2 = agem^2;


* Number children in household [4 categories);
gen nch = .;
replace nch = 1 if childmrd==0;
replace nch = 2 if childmrd==1;
replace nch = 3 if childmrd==2;
replace nch = 4 if childmrd==3 | childmrd==4 | childmrd==5 | childmrd==6 | childmrd==7 | childmrd==10   ;

label var nch "Number of children";
label define nchh 1"No child" 2"One child" 3"Two children" 4"Three and more children"; 
label val nch nchh;
tab nch;

 
 
* Division of housework for female and male persons (anchor and partner) and 3 categorical variable;

replace hhdiv = . if hhdiv <0 | hhdiv >5; /* categorial variable for anchor already in data*/
replace phhdiv  = . if phhdiv <0 | phhdiv >5; /* categorial variable for partner already in data*/

gen hhf = .;
replace hhf = hhdiv  if sex==2;
replace hhf = phhdiv  if psex==2;
 
label var hhf "Housework female";
label define hhff 1"Completely partner" 2"For the most part, my partner" 
3"Split about 50/50" 4"For the most part, me" 5"Completely me";
label val hhf hhff;
tab hhf;
 
gen hhfnew = .;
replace hhfnew = 1 if hhf==4 | hhf==5;
replace hhfnew = 2 if hhf==1 | hhf==2;
replace hhfnew = 3 if hhf==3;
 
label var hhfnew "Housework female 3 cat";
label define hhfneww 1"Me" 2"Partner" 3"Split about 50/50";
label val hhfnew hhfneww;
tab hhfnew; 

gen hhm = .;
replace hhm = hhdiv  if sex==1;
replace hhm = phhdiv  if psex==1;
 
label var hhm "Housework male";
label define hhmm 1"Completely my partner" 2"For the most part, my partner" 
3"Split about 50/50" 4"For the most part, me" 5"Completely me";
label val hhm hhmm;
tab hhm;

gen hhmnew = .;
replace hhmnew = 2 if hhm==4 | hhm==5;
replace hhmnew = 1 if hhm==1 | hhm==2;
replace hhmnew = 3 if hhm==3;

label var hhmnew "Housework female 3 cat";
label define hhmneww 1"Me" 2"Partner" 3"Split about 50/50";
label val hhmnew hhmneww;
tab hhmnew; 

* Equal or unequal responses housework;
gen anhh = 0;
replace anhh = 1 if hhf == 1 & hhm==5;
replace anhh = 1 if hhf==2 & hhm==4;
replace anhh = 1 if hhf==3 & hhm==3;
replace anhh = 1 if hhf==4 & hhm==2;
replace anhh = 1 if hhf==5 & hhm==1;

label var anhh "Response behavior housework";
label define anhhh 0"Not same" 1"Same";
label val anhh anhhh;
tab anhh;


* Division of child care for female and male persons (anchor and partner) and 3 categorical variable;
replace hhcar = . if  hhcar<0 |  hhcar>5; /* categorial variable for anchor already in data*/
replace phhcar = . if phhcar<0 | phhcar>5; /* categorial variable for partner already in data*/

gen ccf = .;
replace ccf = hhcar if sex==2;
replace ccf = phhcar if psex==2;
 
 
 
label var ccf "Child care female";
label define ccff 1"Completely partner" 2"For the most part, my partner" 
3"Split about 50/50" 4"For the most part, me" 5"Completely me";
label val ccf ccff;
tab ccf;


 
 gen ccfnew = .;
replace ccfnew = 1 if ccf==4 | ccf==5;
replace ccfnew = 2 if ccf==1 | ccf==2;
replace ccfnew = 3 if ccf==3;
replace ccfnew = 0 if nch==1;

label var ccfnew "Childcare female 3 cat";
label define ccfneww 1"Me  more" 2"Partner more" 3"Split about 50/50" 4"No child";
label val ccfnew ccfneww;
tab ccfnew; 

gen ccm = .;
replace ccm = hhcar if sex==1;
replace ccm = phhcar if psex==1;
 
label var ccm "Child care male";
label define ccmm 1"Completely my partner" 2"For the most part, my partner" 
3"Split about 50/50" 4"For the most part, me" 5"Completely me";
label val ccm ccmm;
tab ccm;

gen ccmnew = .;
replace ccmnew = 2 if ccm==4 | ccm==5;
replace ccmnew = 1 if ccm==1 | ccm==2;
replace ccmnew = 3 if ccm==3;
replace ccmnew = 0 if nch==1;

label var ccmnew "Childcare male 3 cat";
label define ccmneww 1"Me more" 2"Partner  more" 3"Split about 50/50" 4"No child";
label val ccmnew ccmneww;
tab ccmnew; 


tab hhfnew, gen(hhfnew);
tab hhmnew, gen(hhmnew);
tab ccfnew, gen(ccfnew);
tab ccmnew, gen(ccmnew); 
 
 
*CHILDCARE DIVISON ALL;

gen cc_all =.;
replace cc_all = 1 if ccf==5 | ccm==1;
replace cc_all = 2 if ccf==4 | ccm==2;  
replace cc_all = 3 if ccf==3 | ccm==3;  
replace cc_all = 4 if ccf==2 | ccm==4;
replace cc_all = 5 if ccf==1 | ccm==5; 

label var cc_all "Division of childcare all";
label define cc_allx 1"Completely woman" 2"For the most part, woman" 
3"Split about 50/50" 4"For the most part, man" 5"Completely man";
label val cc_all cc_allx;
 
tab cc_all;


gen cc_all_new = .;
replace cc_all_new = 1 if cc_all==1;
replace cc_all_new = 2 if cc_all==2;
replace cc_all_new = 3 if cc_all==3;
replace cc_all_new = 4 if cc_all==4 | cc_all==5;

label var cc_all_new "Division of childcare all new";
label define cc_all_newx 1"Completely woman" 2"For the most part, woman" 
3"Split about 50/50" 4"For the most part/completely, man";
label val cc_all_new cc_all_newx;
 
tab cc_all_new;

gen cc_all_new_cw = 0 if cc_all_new == 3;
replace  cc_all_new_cw = 1 if cc_all_new == 1;

gen cc_all_new_mw = 0 if cc_all_new == 3;
replace  cc_all_new_mw = 1 if cc_all_new == 2;

gen cc_all_new_m = 0 if cc_all_new == 3;
replace  cc_all_new_m = 1 if cc_all_new == 4;



gen cc_all_new2 = .;
replace cc_all_new2 = 1 if cc_all==2 | cc_all==1;
replace cc_all_new2 = 2 if cc_all==3;
replace cc_all_new2 = 3 if cc_all==4 | cc_all==5;




*HOUSEHOLD DIVISON ALL;

gen hh_all =.;
replace hh_all = 1 if hhf==5 | hhm==1;
replace hh_all = 2 if hhf==4 | hhm==2;  
replace hh_all = 3 if hhf==3 | hhm==3;  
replace hh_all = 4 if hhf==2 | hhm==4;
replace hh_all = 5 if hhf==1 | hhm==5; 

label var hh_all "Division of childcare all";
label define hh_allx 1"Completely woman" 2"For the most part, woman" 
3"Split about 50/50" 4"For the most part, man" 5"Completely man";
label val hh_all hh_allx;
 
tab hh_all;

gen hh_all_new = .;
replace hh_all_new = 1 if hh_all==1;
replace hh_all_new = 2 if hh_all==2;
replace hh_all_new = 3 if hh_all==3;
replace hh_all_new = 4 if hh_all==4 | hh_all==5;

label var hh_all_new "Division of childcare all new";
label define hh_all_newx 1"Completely woman" 2"For the most part, woman" 
3"Split about 50/50" 4"For the most part/completely, man";
label val hh_all_new hh_all_newx;
 
tab hh_all_new;

 
 
* Equal or unequal responses childcare; 
gen ancc = 0;
replace ancc = 1 if ccf == 1 & ccm==5;
replace ancc = 1 if ccf==2 & ccm==4;
replace ancc = 1 if ccf==3 & ccm==3;
replace ancc = 1 if ccf==4 & ccm==2;
replace ancc = 1 if ccf==5 & ccm==5;

label var ancc "Response behavior housework";
label define ancch 0"Not same" 1"Same";
label val ancc ancch;
tab ancc;



* Division of labour (both housework and childcare) for female and male persons;
gen cchhf = .;
replace cchhf = 1 if hhf==1 | ccf==1;
replace cchhf = 2 if hhf==2 | ccf==2;
replace cchhf = 3 if hhf==3 | ccf==3;
replace cchhf = 4 if hhf==4 | ccf==4;
replace cchhf = 5 if hhf==5 | ccf==5;

label var cchhf "Household labour female";
label define cchhff 1"Completely my partner" 2"For the most part, my partner" 
3"Split about 50/50" 4"For the most part, me" 5"Completely me";
label val cchhf cchhff;
tab cchhf;

gen cchhm = .;
replace cchhm = 1 if hhm==1 | ccm==1;
replace cchhm = 2 if hhm==2 | ccm==2;
replace cchhm = 3 if hhm==3 | ccm==3;
replace cchhm = 4 if hhm==4 | ccm==4;
replace cchhm = 5 if hhm==5 | ccm==5;

label var cchhm "Household labour male";
label define cchhmm 1"Completely my partner" 2"For the most part, my partner" 
3"Split about 50/50" 4"For the most part, me" 5"Completely me";
label val cchhm cchhmm;
tab cchhm;

* Relative income in couples (woman's share of pooled individual incomes);
replace incnet = . if incnet<0;   /*Continuous variable for anchor already in data*/
replace pinc2 = . if pinc2<0;  /*Continuous variable for partner already in data*/

gen incf = .;
replace incf = incnet if sex==2;
replace incf = pinc2 if psex==2;

gen incm = .;
replace incm = incnet if sex==1;
replace incm = pinc2 if psex==1;

gen hhinc = incm + incf;

sum hhinc;
sum hhinc if hhinc==0;
  
gen incratiof = (incf)/(hhinc)*100;

* Relative income in couples (Heckert's typology);
gen heckinc = .;
replace heckinc = 1 if incratiof>=0 & incratiof<25;
replace heckinc  = 2 if incratiof>=25 & incratiof<50;
replace heckinc = 3 if incratiof>=50 & incratiof<75;
replace heckinc  = 4 if incratiof>=75 & incratiof<=100;

label var heckinc "Couple typology Heckert";
label define heckincc 1"0-25 trad." 2"25-50 new trad." 
3"50-75 non trad." 4"75-100 rev. trad. ";
label val heckinc heckincc;
tab heckinc;


* Household income to missing if household income<0;
replace hhincnet = . if hhincnet<0;


* Relative education in couples;
gen edf = .;
replace edf = isced if sex==2;  /* categorial variable for anchor already in data*/
replace edf = pisced  if psex==2; /* categorial variable for partner already in data*/

gen edm = .;
replace edm = isced if sex==1;
replace edm = pisced if psex==1;
 
gen edratio = .;
replace edratio = 1 if edm<edf;
replace edratio = 2 if edm>edf;
replace edratio = 3 if edm==edf;
replace edratio = . if edm==. | edf==.;
 
label var edratio "Education Ratio";
label define edratios 1"Woman higher" 2"Woman lower" 3"Same status";
label val edratio edratios;
 

* Relative age in couples;
gen ageratio = .;
replace ageratio = 1 if agem<agef;
replace ageratio = 2 if agem>agef;
replace ageratio = 3 if agem==agef;
 
label var ageratio "Age Ratio";
label define ageratios 1"Woman older" 2"Woman younger" 3"Same age";
label val ageratio ageratios;


 
* VALUES;
replace fraufam = . if fraufam<0;
replace manhh = . if manhh<0;
replace kinleid = . if kinleid<0;

replace pfraufam = . if pfraufam<0;
replace pmanhh = . if pmanhh<0;
replace pkinleid = . if pkinleid<0;

* women more concerned about family than career;
gen wofamf = .;
replace wofamf = fraufam if sex==2;
replace wofamf = pfraufam if psex==2;


label var wofamf "Women family female";
label define wofamfs 1"Disagree"  5"Agree";
label val wofamf wofamfs;

gen wofamm = .;
replace wofamm = fraufam if sex==1;
replace wofamm = pfraufam if psex==1;

label var wofamm "Women family male";
label define wofamms 1"Disagree"  5"Agree";
label val wofamm wofamms;

*men shoud participate equally in hh work;
gen mehhf = .;
replace mehhf = manhh if sex==2;
replace mehhf = pmanhh if psex==2;

label var mehhf "Men housework female";
label define mehhfs 1"Disagree"  5"Agree";
label val mehhf mehhfs;

gen mehhm = .;
replace mehhm = manhh if sex==1;
replace mehhm = pmanhh if psex==1;

label var mehhm "Men housework male";
label define mehhms 1"Disagree"  5"Agree";
label val mehhm mehhms;


*child damaged through mother's work;
gen marnbf = .;
replace marnbf = kinleid if sex==2;
replace marnbf = pkinleid if psex==2;

label var marnbf "Men housework female";
label define  marnbfs 1"Disagree"  5"Agree";
label val  marnbf  marnbfs;

gen marnbm = .;
replace marnbm = kinleid if sex==1;
replace marnbm = pkinleid if psex==1;

label var marnbm "Men housework male";
label define  marnbms 1"Disagree"  5"Agree";
label val  marnbm  marnbms;

 
* Satisfaction for female and male persons;
replace satrel = . if  satrel <0; /*Continuous variable for anchor already in data*/
replace psatrel = . if  psatrel <0; /*Continuous variable for partner already in data*/

gen satf = .;
replace satf =  satrel  if sex==2;
replace satf =  psatrel  if psex==2;

label var satf "Satisfaction relation female";
label define  satfs 1"Very dissatified"  10"Very satisfied";
label val satf  satfs;

gen satm = .;
replace satm =  satrel  if sex==1;
replace satm =  psatrel  if psex==1;

label var satm "Satisfaction relation fmale";
label define  satms 1"Very dissatified"  10"Very satisfied";
label val satm  satms;

* Relative satisfaction in couple;
gen satratio = .;
replace satratio = 1 if satf>satm;
replace satratio = 2 if  satm>satf;
replace satratio = 3 if  satf==satm; 
replace satratio = . if  satf==. | satm==.;

label var satratio "Satisfaction relation Ratio";
label define satratios 1"Woman more" 2"Woman less" 3"Same status";
label val satratio satratios;

* Satisfaction with sex life for male and female persons;
replace satsex = . if  satsex <0;
replace psatsex = . if  psatsex <0;

gen satsexf = .;
replace satsexf =  satsex  if sex==2;
replace satsexf =  psatsex  if psex==2;

label var satsexf "Satisfaction sex female";
label define  satsexfs 1"Very dissatified"  10"Very satisfied";
label val satsexf  satsexfs;

gen satsexm = .;
replace satsexm =  satsex  if sex==1;
replace satsexm =  psatsex  if psex==1;

label var satsexm "Satisfaction sex male";
label define  satsexms 1"Very dissatified"  10"Very satisfied";
label val satsexm  satsexms;


* Relative satisfaction with sex life in couple;
gen satsexratio = .;
replace satsexratio = 1 if satsexf>satsexm;
replace satsexratio = 2 if  satsexm>satsexf;
replace satsexratio = 3 if  satsexf==satsexm;
replace satsexratio = . if  satsexf==. | satsexm==.;

label var satsexratio "Satisfaction sex Ratio";
label define satsexratios 1"Woman more" 2"Woman less" 3"Same status";
label val satsexratio satsexratios;

 
* Migration background for anchor and partner;
gen migback = 0;
replace migback = 1 if mcob>2 | fcob>2 ;
*replace migbach = 0 if (mcob==1 | mcob==2) |  (fcob==1 | fcob==2); 
gen pmigback = 0;
replace pmigback = 1 if pcob>2;
 
* East German origin for partners;
gen peast = 0;
replace peast = 1 if pcob==2;

*Generate dummy variables for categorical variables;
tab nch, gen(nch);
tab rstatus, gen(rstatus); 
tab edratio, gen(edratio);
tab ageratio, gen(ageratio);
*tab employratiod, gen(employratiod);
 
*Household income 
gen hhincnet100 = hhincnet/100;
  
* Child dummy; 
gen ch = .;
replace ch = 1 if nch~=1;
replace ch = 0 if nch==1;

 
* Married dummy; 
gen married = .;
replace married = 1 if rstatus==3;
replace married = 0 if rstatus==2; 

 
*Period variable;
gen period = .;
replace period = 0 if year==2009 | year==2010;
replace period = 1 if year==2011 | year==2012; 
replace period = 2 if year==2013 | year==2014; 
replace period = 3 if year==2015 | year==2016; 
replace period = 4 if year==2017 | year==2018; 
 
* Gesundheit anchor and partners;
replace ph1 = . if ph1<0;
replace ph7 = . if ph7<0;

replace h7 = . if h7<0;
label var h7 "Stunden Schlaf pro Nacht unter der Woche anchor";

replace h1 = . if h7<0;
label var h1 "Gesundheitszustand letzten vier Wochen anchor";
label define h1s 1"Schlecht" 2"Weniger gut" 3"Zufriedenstellend" 4"Gut" 5"Sehr gut";
label val h1 h1s;
tab h1;

replace ph7 = . if h7<0;
label var ph7 "Stunden Schlaf pro Nacht unter der Woche partner";

replace ph1 = . if h7<0;
label var ph1 "Gesundheitszustand letzten vier Wochen partner";
label define ph1s 1"Schlecht" 2"Weniger gut" 3"Zufriedenstellend" 4"Gut" 5"Sehr gut";
label val ph1 ph1s;
tab ph1;


*********************************************************************************************************************************************************************************************
*workplace related variables
*********************************************************************************************************************************************************************************************

* Isco 08 status groups anchor;
gen iscoall = .; 
replace iscoall = 1 if isco08<2111;
replace iscoall = 2 if isco08>=2111 & isco08<3111;
replace iscoall = 3 if isco08>=3111 & isco08<4111;
replace iscoall = 4 if isco08>=4111 & isco08<5111;
replace iscoall = 5 if isco08>=5111 & isco08<6111;
replace iscoall = 6 if isco08>=6111 & isco08<8111;
replace iscoall = 7 if isco08>=8111 & isco08<9111;
replace iscoall = 8 if isco08>=9111 & isco08<=9629;
*replace iscoall = 9 if isco08>=110 & isco08<=310;

label var iscoall "ISCO 08";
label define iscolall 1"Legislators, senior officicals, managers" 2"Professionals" 3"Associate professionals, technicans" 4"Clerks" 5"Service Workers" 6"Handwerk u.a." 7"Plant and machine operators and assemblers" 8"Elemantary workers" ;
label val iscoall iscolall;
 
gen isconew = .;
replace isconew = 1 if iscoall==1 | iscoall==2;
replace isconew = 2 if iscoall==3;
replace isconew = 3 if iscoall==4 | iscoall==5;
replace isconew = 4 if iscoall==6 ;
replace isconew = 5 if iscoall==7;
replace isconew = 6 if iscoall==8;
 
label var isconew "ISCO 08 6 Kat";
label define isconeww 1"Legislators, senior officicals, managers, professionals" 2"Associate professionals, technicans" 3"Clerks, Service Workers" 4"Handwerk u.a." 5"Plant and machine operators and assemblers" 6"Elemantary workers" ;
label val isconew isconeww; 
 
*Occupational Status anchor and partners;
gen status = .;
replace status = 1 if job2<=30;
replace status = 2 if job2>=40 & job2<=43;
replace status = 4 if job2==51;
replace status = 5 if job2==52;
replace status = 6 if job2==53 | job2==54;
replace status = 3 if job2>=60 & job2<=64;
 
label var status "Occupational Status";
label define statuss 1"Self" 2"Civil service" 3"Worker" 4"Employee" 5"Qualified Employee" 6"Highly qualified employee/leadership" ;
label val status statuss;
tab status;

gen self = 0;
replace self = 1 if status==1;

gen civil = 0;
replace civil = 1 if status==2;

gen worker = 0;
replace worker = 1 if status==3;

gen employee = 0;
replace employee = 1 if status==4 | status==5;

gen hemployee = 0;
replace hemployee = 1 if status==6;

 
rename pstatus pocc;

gen pstatus = .;
replace pstatus = 1 if pjob2<=30;
replace pstatus = 2 if pjob2>=40 & pjob2<=43;
replace pstatus = 4 if pjob2==51;
replace pstatus = 5 if pjob2==52;
replace pstatus = 6 if pjob2==53 | pjob2==54;
replace pstatus = 3 if pjob2>=60 & pjob2<=64;
replace pstatus = . if pstatus==0;	
 
label var pstatus "Occupational Status Partner";
label define pstatuss 1"Self" 2"Civil service" 3"Worker" 4"Employee" 5"Qualified Employee" 6"Highly qualified employee/leadership" ;
label val pstatus pstatuss;
tab pstatus;


gen pselfs = 0;
replace pselfs = 1 if pstatus==1;

gen pcivil = 0;
replace pcivil = 1 if pstatus==2;

gen pworker = 0;
replace pworker = 1 if pstatus==3;

gen pemployee = 0;
replace pemployee = 1 if pstatus==4 | pstatus==5;

gen phemployee = 0;
replace phemployee = 1 if pstatus==6;



* Part-Time, full-time;
replace lfs = . if lfs<0;

gen employ = .;
replace employ = 1 if lfs==9;
replace employ = 2 if lfs==10 ;
replace employ = 3 if lfs==11 ;
*replace employ = 4 if lfs==2 | lfs==3 | lfs==4;

label var employ "Employment status anchor";
label define  employy 1"Full-time" 2"Part-time" 3"Marginal";
label val employ employy; 

 
recode employ (3=2)
 
 
replace plfs = . if plfs<0;

gen pemploy = .;
replace pemploy = 1 if plfs==9 | plfs==12;
replace pemploy = 2 if plfs==10 ;
replace pemploy = 3 if plfs==11 ;
replace pemploy = 4 if plfs==2 | plfs==3 | plfs==4;
 
label var pemploy "Employment status partner";
label define  pemployy 1"Full-time" 2"Part-time" 3"Marginal" 4"Not working";
label val pemploy pemployy; 
 
gen employf = .;
replace employf = employ if sex==2;
replace employf = pemploy if psex==2;

label var employf "Employment female";
label define  employff 1"Full-time" 2"Part-time" 3"Marginal" 4"Not working";
label val employf employff;

gen employm = .;
replace employm = employ if sex==1;
replace employm = pemploy if psex==1;
 

label var employm "Employment male";
label define  employmm 1"Full-time" 2"Part-time" 3"Not working" 4"Education";
label val employm employmm;


 
*Shift work and atypical working time;
gen shift = .;
replace shift = job8;
sum shift;

rename job9 evening;
rename job10 location;
rename job11 chlocation;

rename job12 night;
replace night= . if night<0;
label var night "Nächte nicht zu Hause berufsbedingt letzten 3 Monate anchor";

replace pnight= . if pnight<0;
label var pnight "Nächte nicht zu Hause berufsbedingt letzten 3 Monate partner";
 
gen location3 = .;
replace location3 = 2 if location==1 | location==2;
replace location3 = 1 if location==3;
replace location3 = 3 if location==4;


gen chlocation2 = 0;
replace chlocation2 = 1 if chlocation~=.; 
 

replace ykage = 0 if nch==1; 
								  


*Working from home;

gen heimarbeit = 1 if location==1;
replace heimarbeit = 0 if location==2 | location==3 | location==4;


gen ho = 0 if location==2 | location==3 | location==4;
replace ho = 1 if location==1 | (job26>=1 & job26<=5);
replace ho = . if year~=2018 & year~=2019 & year~=2020;

tab heimarbeit;
tab ho;

 
 
gen hh_all_cw = 0 if hh_all==2;
replace hh_all_cw = 1 if hh_all==1;

gen hh_all_mw = 0 if hh_all==2;
replace hh_all_mw = 1 if hh_all==3;


gen hh_all_cm = 0 if hh_all==2;
replace hh_all_cm = 1 if hh_all==5;

gen hh_all_mm = 0 if hh_all==2;
replace hh_all_mm = 1 if hh_all==4;


 
gen hhf_cw = 0 if hhf==4;
replace hhf_cw = 1 if hhf==5;
tab hhf_cw;

gen hhf_e = 0 if hhf==4;
replace hhf_e = 1 if hhf==3;
tab hhf_e;

gen hhf_cm = 0 if hhf==4;
replace hhf_cm = 1 if hhf==1;
tab hhf_cm;

gen hhf_mm = 0 if hhf==4;
replace hhf_mm = 1 if hhf==2;
tab hhf_mm;


gen hhf_ee = 0 if hhfnew==1;
replace hhf_ee = 1 if hhfnew==3;

gen hhf_m = 0 if hhfnew==3;
replace hhf_m = 1 if hhfnew==2;



gen hhfnew_2 = .;
replace hhfnew_2 = 1 if hhf==1 | hhf==2;
replace hhfnew_2 = 2 if hhf==3;
replace hhfnew_2 = 3 if hhf==4;
replace hhfnew_2 = 4 if hhf==5;

 
gen ccfnew_2 = .;
replace ccfnew_2 = 1 if ccf==1 | ccf==2;
replace ccfnew_2 = 2 if ccf==3;
replace ccfnew_2 = 3 if ccf==4;
replace ccfnew_2 = 4 if ccf==5;


gen hhmnew_2 = .;
replace hhmnew_2 = 1 if hhm==1  ;
replace hhmnew_2 = 2 if hhm==2;
replace hhmnew_2 = 3 if hhm==3;
replace hhmnew_2 = 4 if hhm==5 | hhm==4;

 
gen ccmnew_2 = .;
replace ccmnew_2 = 1 if ccm==1  ;
replace ccmnew_2 = 2 if ccm==2;
replace ccmnew_2 = 3 if ccm==3;
replace ccmnew_2 = 4 if ccm==5 | ccm==4;


foreach var in job27i1 job27i2 job27i3 job27i4 job27i5 job27i6  job28 {;
bysort id (year): egen `var'y  = max(`var');
};

 
*Index work family commitment;

alpha job27i1y job27i4y job27i6y;


gen wimportance = (job27i1y + job27i4y + job27i6y);
sum  wimportance;

gen iw_index = (wimportance-3)/12;
 
alpha job27i2y job27i3y job27i5y;


gen fimportance = (job27i2y + job27i3y + job27i5y);
sum  fimportance;

gen if_index = (fimportance-3)/12;

*MEAN work family importance;

foreach var in   job27i2  job27i3 job27i5   {;
gen `var'_revers = .;
replace `var'_revers = 1 if `var'==5;
replace `var'_revers = 2 if `var'==4;
replace `var'_revers = 3 if `var'==3;   
replace `var'_revers = 4 if `var'==2; 
replace `var'_revers = 5 if `var'==1; 

label define `var'wfi 1"Stimme voll und ganz zu" 5"Stimme überhaupt nicht zur";
label val `var'_revers `var'wfi ;

};

foreach var in   job27i2y  job27i3y job27i5y   {;
gen `var'_revers = .;
replace `var'_revers = 1 if `var'==5;
replace `var'_revers = 2 if `var'==4;
replace `var'_revers = 3 if `var'==3;   
replace `var'_revers = 4 if `var'==2; 
replace `var'_revers = 5 if `var'==1; 

label define `var'wfi 1"Stimme voll und ganz zu" 5"Stimme überhaupt nicht zur";
label val `var'_revers `var'wfi ;

};


alpha job27i2_revers job27i3_revers job27i5_revers job27i1   job27i4   job27i6;

gen wfi_sum = (job27i2_revers + job27i3_revers + job27i5_revers + job27i1 +   job27i4  + job27i6);
gen wfi_index = (wfi_sum -6)/24;
sum wfi_index;

egen wfi_mean = rowmean(job27i2_revers  job27i3_revers job27i5_revers job27i1   job27i4   job27i6);
sum wfi_mean;



gen wfi_sumy = (job27i2y_revers + job27i3y_revers + job27i5y_revers + job27i1y +   job27i4y  + job27i6y);
gen wfi_indexy = (wfi_sumy -6)/24;
sum wfi_indexy;

egen wfi_meany = rowmean(job27i2y_revers  job27i3y_revers job27i5y_revers job27i1y   job27i4y   job27i6y);
sum wfi_meany;



*Gender parenthood;

gen genparent = .;
replace genparent = 1 if sex_gen==1 & nch==1;
replace genparent = 2 if sex_gen==2 & nch==1;
replace genparent = 3 if sex_gen==1 & (nch>=2 & nch<=4);
replace genparent = 4 if sex_gen==2 & (nch>=2 & nch<=4);

tab genparent sex_gen;
tab genparent nch; 
 
label var genparent "Gendered parental status";
label define genparentx 1"Childless men" 2"Childless women" 3"Fathers" 4"Mothers";
label val genparent genparentx;
tab genparent; 

tab genparent, gen(genparent); 
 
 


 
save "`path'\varpairfamlong.dta", replace;


clear;
exit;

 